API
===

Welcome to the API page for QPrism. This page is an overall class and function reference,
please refer to the individual class and function page for further details. For reference on 
concepts repeated across the API, see :doc:`glossary`.

Video
-----
.. toctree::
   Video_DQM

Audio
-----
.. toctree::
   Audio_DQM

Sensor
------

.. toctree::
   DQM_single_file
   DQM_multiple_file
